VoiceData

Struct VoiceData 

#[non_exhaustive]
pub struct VoiceData { pub packet: Option<RtpData>, pub decoded_voice: Option<Vec<i16>>, }
Voice packet and audio data for a single user, from a single tick.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
packet: Option<RtpData>

RTP packet clocked out for this tick.

If None, then the packet was lost, and Self::decoded_voice may include around one codec delay’s worth of audio.

decoded_voice: Option<Vec<i16>>

PCM audio obtained from a user.

Valid audio data (Some(audio) where audio.len >= 0) typically contains 20ms of 16-bit PCM audio using native endianness. This defaults to stereo audio at 48kHz, and can be configured via DecodeConfig::sample_rate and DecodeConfig::sample_rate – channels are interleaved (i.e., L, R, L, R, ...) if stereo.

This value will be None if Songbird is not configured to decode audio.